@@ -308,7 +308,7 @@ g_daemon_vfs_init (GDaemonVfs *vfs)
   vfs->wrapped_vfs = g_vfs_get_local ();
 
   /* Use the old .gvfs location as fallback, not .cache/gvfs */
-  if (g_get_user_runtime_dir() == g_get_user_cache_dir ())
+  if (g_strcmp0 (g_get_user_runtime_dir(), g_get_user_cache_dir ()) == 0)
     file = g_build_filename (g_get_home_dir(), ".gvfs", NULL);
   else
     file = g_build_filename (g_get_user_runtime_dir(), "gvfs", NULL);
